import 'dart:convert';
import 'dart:io' show Platform;

import 'package:vdotok_stream/src/signaling/socketManager/socketManager.dart';

typedef void OnMessageCallback(dynamic msg);
typedef void OnCloseCallback(int code, String reason);
typedef void OnOpenCallback();

class WebSocketConnection {
  String url;
  var _socket;
  String _protocol;
  int _timeOutInSec = 10;
  static final WebSocketConnection _instance =
      WebSocketConnection._privateConstructor();
  static WebSocketConnection get instance => _instance;
  WebSocketConnection._privateConstructor();
  WebSocketConnection({this.url});
  OnOpenCallback onOpen;
  OnMessageCallback onMessage;
  OnCloseCallback onClose;

  connect() async {
    try {
      //_socket = await WebSocket.connect(_url);
      _socket = await _connectForSelfSignedCert(url);
      onOpen?.call();
      _socket.stream.listen((data) {
        onMessage?.call(data);
      }, onDone: () {
        onClose?.call(_socket.closeCode, _socket.closeReason);
      });
    } catch (e) {
      onClose?.call(500, e.toString());
    }
  }

  send(Map<String, dynamic> data) {
    print("pong");
    if (_socket != null) {
      _socket.sink.add(json.encode(data));
    }
  }

  close() {
    if (_socket != null) _socket.sink.close();
  }

  Future<dynamic> _connectForSelfSignedCert(url) async {
    try {
      dynamic channel = await SocketManager.instance.connect(url);
      return channel;
    } catch (e) {
      onClose.call(500, e.toString());
    }
  }
}
